@@ -16,7 +16,7 @@ has missing_after => 86400;
 has remove_after  => 864000;
 has tasks         => sub { {} };
 
-our $VERSION = '4.01';
+our $VERSION = '4.02';
 
 sub add_task { ($_[0]->tasks->{$_[1]} = $_[2]) and return $_[0] }
 
@@ -114,7 +114,7 @@ Minion - Job queue
 
 =head1 DESCRIPTION
 
-L<Minion> is a job queue for the L<Mojolicious|http://mojolicio.us> real-time
+L<Minion> is a job queue for the L<Mojolicious|http://mojolicious.org> real-time
 web framework with support for multiple named queues, priorities, delayed jobs,
 job results, retries with backoff, distributed workers, parallel processing and
 multiple backends (such as L<PostgreSQL|http://www.postgresql.org>).
@@ -132,15 +132,15 @@ that's not super fast.
   # Slow task
   app->minion->add_task(poke_mojo => sub {
     my $job = shift;
-    $job->app->ua->get('mojolicio.us');
-    $job->app->log->debug('We have poked mojolicio.us for a visitor');
+    $job->app->ua->get('mojolicious.org');
+    $job->app->log->debug('We have poked mojolicious.org for a visitor');
   });
 
   # Perform job in a background worker process
   get '/' => sub {
     my $c = shift;
     $c->minion->enqueue('poke_mojo');
-    $c->render(text => 'We will poke mojolicio.us for you soon.');
+    $c->render(text => 'We will poke mojolicious.org for you soon.');
   };
 
   app->start;
@@ -174,8 +174,8 @@ plugins.
     my ($self, $app) = @_;
     $app->minion->add_task(poke_mojo => sub {
       my $job = shift;
-      $job->app->ua->get('mojolicio.us');
-      $job->app->log->debug('We have poked mojolicio.us for a visitor');
+      $job->app->ua->get('mojolicious.org');
+      $job->app->log->debug('We have poked mojolicious.org for a visitor');
     });
   }
 
@@ -275,7 +275,7 @@ following new ones.
 
   $minion = $minion->add_task(foo => sub {...});
 
-Register a new task.
+Register a task.
 
   # Job with result
   $minion->add_task(add => sub {
@@ -484,7 +484,7 @@ Paul Williams
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (C) 2014-2015, Sebastian Riedel.
+Copyright (C) 2014-2016, Sebastian Riedel.
 
 This program is free software, you can redistribute it and/or modify it under
 the terms of the Artistic License version 2.0.
@@ -492,6 +492,6 @@ the terms of the Artistic License version 2.0.
 =head1 SEE ALSO
 
 L<https://github.com/kraih/minion>, L<Mojolicious::Guides>,
-L<http://mojolicio.us>.
+L<http://mojolicious.org>.
 
 =cut
