@@ -261,8 +261,8 @@ implements the following new ones.
   my $job_info = $backend->dequeue($worker_id, 0.5);
   my $job_info = $backend->dequeue($worker_id, 0.5, {queues => ['important']});
 
-Wait for job, dequeue it and transition from C<inactive> to C<active> state or
-return C<undef> if queues were empty.
+Wait a given amount of time in seconds for a job, dequeue it and transition from
+C<inactive> to C<active> state, or return C<undef> if queues were empty.
 
 These options are currently available:
 
@@ -368,7 +368,7 @@ Transition from C<active> to C<finished> state.
 
   my $job_info = $backend->job_info($job_id);
 
-Get information about a job or return C<undef> if job does not exist.
+Get information about a job, or return C<undef> if job does not exist.
 
   # Check job state
   my $state = $backend->job_info($job_id)->{state};
@@ -618,7 +618,7 @@ Unregister worker.
 
   my $worker_info = $backend->worker_info($worker_id);
 
-Get information about a worker or return C<undef> if worker does not exist.
+Get information about a worker, or return C<undef> if worker does not exist.
 
   # Check worker host
   my $host = $backend->worker_info($worker_id)->{host};
@@ -661,7 +661,7 @@ Time worker was started.
 
 =head1 SEE ALSO
 
-L<Minion>, L<Mojolicious::Guides>, L<http://mojolicio.us>.
+L<Minion>, L<Mojolicious::Guides>, L<http://mojolicious.org>.
 
 =cut
 
