@@ -133,6 +133,6 @@ Run this command.
 
 =head1 SEE ALSO
 
-L<Minion>, L<Mojolicious::Guides>, L<http://mojolicio.us>.
+L<Minion>, L<Mojolicious::Guides>, L<http://mojolicious.org>.
 
 =cut
